OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Η έκδοση {version} είναι διαθέσιμη. Δείτε περισσότερες πληροφορίες για το πως να κάνετε την ενημέρωση.",
    "Updater" : "Εφαρμογή Ενημέρωσης",
    "A new version is available: %s" : "Μία νέα έκδοση είναι διαθέσιμη: %s",
    "Open updater" : "Άνοιγμα εφαρμογής ενημέρωσης"
},
"nplurals=2; plural=(n != 1);");
